@@ -6,13 +6,25 @@ main_help_message: str = "本骰娘由nonebot2强力驱动\n" \
                          "    #   多轮检定\n" \
                          "    bp  奖励骰&惩罚骰\n" \
                          "    +/- 附加计算  todo\n" \
-                         ".sc   疯狂检定  todo\n" \
+                         ".sc   疯狂检定\n" \
                          ".st   射击命中判定\n" \
                          ".ti   临时疯狂症状\n" \
                          ".li   总结疯狂症状\n" \
                          ".coc  coc角色作成\n" \
                          ".help 帮助信息\n" \
-                         ".en   技能成长  todo"
+                         ".en   技能成长"
+r_help_message: str = ".r[dah#bp] a_number [+/-]ex_number\n" \
+                      "d：骰子设定指令,标准格式为xdy，x为骰子数量y为骰子面数；\n" \
+                      "a：检定指令，根据后续a_number设定数值检定；\n" \
+                      "h：暗骰指令，骰子结构将会私聊发送给该指令者；\n" \
+                      "#：多轮投掷指令，#后接数字即可设定多轮投掷；\n" \
+                      "bp：奖励骰与惩罚骰；\n" \
+                      "+/-：附加计算指令，目前仅支持数字"
+sc_help_message: str = ".sc success/failure san_number\n" \
+                       "success：判定成功降低 san 值，支持 x 或 xdy 语法（ x 与 y 为数字）；\n" \
+                       "failure：判定失败降低 san 值，支持语法如上；\n" \
+                       "san_number：当前 san 值。"
+en_help_message: str = ".en skill_level\nskill_level：需要成长的技能当前等级。"
 temporary_madness = [
     "1) 失忆: 调查员会发现自己身处于一个安全的地点却没有任何来到这里的记忆。例如，调查员前一刻还在家中吃着早饭，下一刻就已经直面着不知名的怪物。这将会持续1D10轮。",
     "2) 假性残疾:调查员陷入了心理性的失明，失聪以及躯体缺失感中，持续1D10轮。",
